<?php

declare(strict_types=1);

namespace Drupal\sophron_guesser;

use Drupal\Core\File\Event\MimeTypeMapLoadedEvent;
use Drupal\Core\File\MimeType\MimeTypeMapFactory;
use Drupal\Core\File\MimeType\MimeTypeMapInterface;
use Drupal\sophron\MimeMapManagerInterface;

/**
 * Factory for creating the MIME type map.
 */
class SophronMimeTypeMapFactory extends MimeTypeMapFactory {

  /**
   * Creates an instance of the Sophron MIME type map.
   *
   * @param \Drupal\sophron\MimeMapManagerInterface $mimeMapManager
   *   The Sophron MIME map manager service.
   *
   * @return \Drupal\Core\File\MimeType\MimeTypeMapInterface
   *   The MIME type map.
   */
  public function createSophronMap(MimeMapManagerInterface $mimeMapManager): MimeTypeMapInterface {
    $map = new SophronMimeTypeMap($mimeMapManager);
    $this->eventDispatcher->dispatch(new MimeTypeMapLoadedEvent($map));
    return $map;
  }

}
